{% load i18n %}
{% load dict_key_extras %}

<form id="form_select_template">
		<input  type="radio" name="curate_form" value="new"> <b class="pop_curate_label" id ="form_role_title"></b>
		{{new_form}}

		<div class="hidden">
		<input type="radio" name="curate_form" value="open"> <b class="pop_curate_label">Open an existing {% trans "form_label" %}: </b>
		{{open_form}}
		</div>

		<input type="radio" name="curate_form" value="upload"> <b class="pop_curate_label">Open an existing XML document: </b>
		{{upload_form}}

	{{hidden_form}}
</form>