{% extends 'core_main_app/_render/admin/theme/tools/modal.html' %}
{% load i18n %}

{% block modal_id %}save-form-registry-modal{% endblock %}
{% block modal_title %}Save succesful{% endblock %}

{% block modal_body %}
This document is saved as unpublished, do you want to publish it?
{% endblock %}

{% block modal_footer %}
    <div class="container">
        <div class="row">
            <div class="col-8">
                <div class="d-flex justify-content-start">
                    <a class="btn btn-danger mr-1" href="{% url 'core_curate_index' %}">
                        <i class="fa fa-home"></i> No, go to curate page
                    </a>
                    <a class="btn btn-danger" href="{% url 'core_dashboard_records' %}">
                        <i class="fa fa-home"></i> No, go to resource page
                    </a>
                </div>
            </div>
            <div class="col-4">
                <div class="d-flex justify-content-end">
                    <button class="btn btn-primary publish">
                        <i class="fa fa-check"></i> Publish it
                    </button>
                </div>
            </div>
        </div>
    </div>
{% endblock %}
